@@ -14,12 +14,12 @@ except ImportError:
 from tiddlyweb.filters import parse_for_filters
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
-from tiddlyweb.store import NoBagError, StoreError
+from tiddlyweb.store import NoBagError, StoreError, NoTiddlerError
 from tiddlyweb import control
 from tiddlyweb.web.handler.recipe import get_tiddlers
 from tiddlyweb.web.handler.tiddler import get as get_tiddler
 from tiddlyweb.web.http import HTTP403
-from tiddlyweb.web.util import get_serialize_type
+from tiddlyweb.web.util import get_serialize_type, encode_name
 
 from tiddlywebplugins.utils import require_any_user
 
@@ -29,6 +29,7 @@ from tiddlywebplugins.tiddlyspace.space import Space
 
 
 SPACE_SERVER_SETTINGS = 'ServerSettings'
+DEFAULT_NEWUSER_APP = 'apps'
 
 
 def friendly_uri(environ, start_response):
@@ -82,7 +83,7 @@ def get_space_tiddlers(environ, start_response):
     # If we are a wiki read ServerSettings, but ignore index
     if ('betaserialization' in serializer
             or 'betalazyserialization' in serializer):
-        _, lazy = update_space_settings(environ, space_name)
+        _, lazy, _ = update_space_settings(environ, space_name)
         if lazy:
             environ['tiddlyweb.type'] = 'text/x-ltiddlywiki'
     return get_tiddlers(environ, start_response)
@@ -111,11 +112,17 @@ def serve_space(environ, start_response, http_host):
     environ['wsgiorg.routing_args'][1]['recipe_name'] = recipe_name.encode(
             'UTF-8')
     _, mime_type = get_serialize_type(environ)
-    index, lazy = update_space_settings(environ, space_name)
+    index, lazy, redirect_required = update_space_settings(environ, space_name)
     if index:
-        environ['wsgiorg.routing_args'][1]['tiddler_name'] = index.encode(
-                'UTF-8')
-        return get_tiddler(environ, start_response)
+        title = index.encode('UTF-8')
+        environ['wsgiorg.routing_args'][1]['tiddler_name'] = title
+        if not redirect_required:
+            return get_tiddler(environ, start_response)
+        else:
+            scheme = environ['tiddlyweb.config']['server_host']['scheme']
+            start_response('302 Found', [('Location', "%s://%s/%s" % (
+                scheme, determine_host(environ)[0], encode_name(index)))])
+            return ""
     if 'text/html' in mime_type:
         if lazy:
             environ['tiddlyweb.type'] = 'text/x-ltiddlywiki'
@@ -124,6 +131,28 @@ def serve_space(environ, start_response, http_host):
     return get_tiddlers(environ, start_response)
 
 
+def _figure_default_index(environ, bag_name, space, index=None):
+    """
+    if an app hasn't been specified, check whether the space is new or old.
+    old users should get the old default: TiddlyWiki, new users should get
+    the new default: the app switcher. The presence of a spaceSetupFlag
+    tiddler is the test for this.
+    """
+    store = environ['tiddlyweb.store']
+    if not index and space.name != 'frontpage':
+        setupFlag = Tiddler('%sSetupFlag' % space.name, bag_name)
+        try:
+            setupFlag = store.get(setupFlag)
+        except NoTiddlerError:
+            setupFlag.bag = space.private_bag()
+            try:
+                setupFlag = store.get(setupFlag)
+            except NoTiddlerError:
+                index = DEFAULT_NEWUSER_APP
+
+    return index
+
+
 def update_space_settings(environ, name):
     """
     Read a tiddler named by SPACE_SERVER_SETTINGS in the current
@@ -141,7 +170,7 @@ def update_space_settings(environ, name):
         tiddler = store.get(tiddler)
         data_text = tiddler.text
     except StoreError:
-        return None, False
+        return _figure_default_index(environ, bag_name, space), False, False
 
     query_strings = []
     index = ''
@@ -161,6 +190,8 @@ def update_space_settings(environ, name):
         except ValueError:
             pass
 
+    index = _figure_default_index(environ, bag_name, space, index)
+
     query_string = ';'.join(query_strings)
 
     filters, leftovers = parse_for_filters(query_string, environ)
@@ -170,7 +201,10 @@ def update_space_settings(environ, name):
         [(key, [value for value in values])
             for key, values in query_data.items()]))
 
-    return index, lazy
+    if index:
+        return index, lazy, True
+    else:
+        return index, lazy, False
 
 
 def _setup_friendly_environ(environ):
